#!/usr/bin/python
"""Shelf - temporarily set aside changes, then bring them back."""

import bzrlib.commands
import bzrlib.branch
from bzrlib.errors import BzrCommandError
from shelf import Shelf

class cmd_shelve(bzrlib.commands.Command):
    """Temporarily remove some changes from the current tree.
    Use 'unshelve' to restore these changes.

    If filenames are specified, only changes to those files will be unshelved.
    If a revision is specified, all changes since that revision will may be
    unshelved.
    """
    takes_args = ['file*']
    takes_options = ['all', 'message', 'revision']
    def run(self, all=False, file_list=None, message=None, revision=None):
        if file_list is not None and len(file_list) > 0:
            branchdir = file_list[0]
        else:
            branchdir = '.'

        if revision is not None and revision:
            if len(revision) == 1:
                revision = revision[0]
            else:
                raise BzrCommandError("shelve only accepts a single revision "
                                  "parameter.")

        s = Shelf(branchdir)
        return s.shelve(all, message, revision, file_list)

class cmd_unshelve(bzrlib.commands.Command):
    """Restore previously-shelved changes to the current tree.
    See also 'shelve'.
    """
    def run(self):
        s = Shelf('.')
        return s.unshelve()

bzrlib.commands.register_command(cmd_shelve)
bzrlib.commands.register_command(cmd_unshelve)

def test_suite():
    from bzrlib.selftest.TestUtil import TestLoader
    import tests
    return TestLoader().loadTestsFromModule(tests)
